@@ -1,10 +1,10 @@
-var compactable = require('./compactable');
+var configuration = require('../configuration');
 
 function restoreWithComponents(property) {
-  var descriptor = compactable[property.name];
+  var descriptor = configuration[property.name];
 
   if (descriptor && descriptor.shorthand) {
-    return descriptor.restore(property, compactable);
+    return descriptor.restore(property, configuration);
   } else {
     return property.value;
   }
