@@ -135,6 +135,21 @@ vows.describe('module tests').addBatch({
       assert.isEmpty(minified.warnings);
     }
   },
+  'warnings on missing explicit `rebaseTo`': {
+    'topic': function () {
+      return new CleanCSS({rebase: true}).minify('@import url(test/fixtures/partials/with-commented-import.css);');
+    },
+    'should minify correctly': function (error, minified) {
+      assert.equal(minified.styles, '@font-face{font-family:Font;src:url("/path/to/font")}');
+    },
+    'should raise no errors': function (error, minified) {
+      assert.isEmpty(minified.errors);
+    },
+    'should raise one warning': function (error, minified) {
+      assert.lengthOf(minified.warnings, 1);
+      assert.isTrue(minified.warnings[0].indexOf('`rebaseTo: process.cwd()`') > -1);
+    }
+  },
   'warnings on extra closing brace': {
     'topic': function () {
       return new CleanCSS().minify('a{display:block}}');
@@ -268,28 +283,28 @@ vows.describe('module tests').addBatch({
         new CleanCSS().minify('@import "test/fixtures/partials/with-commented-import.css";', this.callback);
       },
       'has right output': function (errors, minified) {
-        assert.equal(minified.styles, '@font-face{font-family:Font;src:url(/path/to/font)}');
+        assert.equal(minified.styles, '@font-face{font-family:Font;src:url("/path/to/font")}');
       }
     }
   },
   'external imports and no callback': {
     'without content': {
       'topic': function () {
-        return new CleanCSS().minify('@import url(http://jakubpawlowicz.com/styles.css);');
+        return new CleanCSS().minify('@import url(http://clean-css.github.io/styles.css);');
       },
       'has right output': function (minified) {
-        assert.equal(minified.styles, '@import url(http://jakubpawlowicz.com/styles.css);');
+        assert.equal(minified.styles, '@import url(http://clean-css.github.io/styles.css);');
       },
       'has no errors': function (minified) {
         assert.isEmpty(minified.errors);
       },
       'has a warning': function (minified) {
-        assert.deepEqual(minified.warnings, ['Skipping remote @import of "http://jakubpawlowicz.com/styles.css" as no callback given.']);
+        assert.deepEqual(minified.warnings, ['Skipping remote @import of "http://clean-css.github.io/styles.css" as no callback given.']);
       }
     },
     'after content': {
       'topic': function () {
-        return new CleanCSS().minify('a{color:red}@import url(http://jakubpawlowicz.com/styles.css);');
+        return new CleanCSS().minify('a{color:red}@import url(http://clean-css.github.io/styles.css);');
       },
       'has right output': function (minified) {
         assert.equal(minified.styles, 'a{color:red}');
@@ -298,12 +313,12 @@ vows.describe('module tests').addBatch({
         assert.isEmpty(minified.errors);
       },
       'has a warning': function (minified) {
-        assert.deepEqual(minified.warnings, ['Ignoring remote @import of "http://jakubpawlowicz.com/styles.css" as no callback given and after other content.']);
+        assert.deepEqual(minified.warnings, ['Ignoring remote @import of "http://clean-css.github.io/styles.css" as no callback given and after other content.']);
       }
     },
     'after local import': {
       'topic': function () {
-        return new CleanCSS().minify('@import url(test/fixtures/partials/one.css);@import url(http://jakubpawlowicz.com/styles.css);');
+        return new CleanCSS().minify('@import url(test/fixtures/partials/one.css);@import url(http://clean-css.github.io/styles.css);');
       },
       'has right output': function (minified) {
         assert.equal(minified.styles, '.one{color:red}');
@@ -312,30 +327,30 @@ vows.describe('module tests').addBatch({
         assert.isEmpty(minified.errors);
       },
       'has a warning': function (minified) {
-        assert.deepEqual(minified.warnings, ['Skipping remote @import of "http://jakubpawlowicz.com/styles.css" as no callback given.']);
+        assert.deepEqual(minified.warnings, ['Skipping remote @import of "http://clean-css.github.io/styles.css" as no callback given.']);
       }
     },
     'after remote import': {
       'topic': function () {
-        return new CleanCSS().minify('@import url(http://jakubpawlowicz.com/reset.css);@import url(http://jakubpawlowicz.com/styles.css);');
+        return new CleanCSS().minify('@import url(http://clean-css.github.io/reset.css);@import url(http://clean-css.github.io/styles.css);');
       },
       'has right output': function (minified) {
-        assert.equal(minified.styles, '@import url(http://jakubpawlowicz.com/reset.css);@import url(http://jakubpawlowicz.com/styles.css);');
+        assert.equal(minified.styles, '@import url(http://clean-css.github.io/reset.css);@import url(http://clean-css.github.io/styles.css);');
       },
       'has no errors': function (minified) {
         assert.isEmpty(minified.errors);
       },
       'has a warning': function (minified) {
         assert.deepEqual(minified.warnings, [
-          'Skipping remote @import of "http://jakubpawlowicz.com/reset.css" as no callback given.',
-          'Skipping remote @import of "http://jakubpawlowicz.com/styles.css" as no callback given.'
+          'Skipping remote @import of "http://clean-css.github.io/reset.css" as no callback given.',
+          'Skipping remote @import of "http://clean-css.github.io/styles.css" as no callback given.'
         ]);
       }
     }
   },
   'buffer passed in': {
     'topic': function () {
-      return new CleanCSS().minify(new Buffer('@import url(test/fixtures/partials/one.css);'));
+      return new CleanCSS().minify(Buffer.from('@import url(test/fixtures/partials/one.css);'));
     },
     'should be processed correctly': function (minified) {
       assert.equal(minified.styles, '.one{color:red}');
@@ -410,19 +425,23 @@ vows.describe('module tests').addBatch({
       assert.instanceOf(minified.sourceMap, SourceMapGenerator);
     }
   },
-  'arbitrary property transformations': {
+  'arbitrary property transformations now via plugins (since 5.0)': {
     'allows changing property value': {
       'topic': function () {
         return new CleanCSS({
-          level: {
-            1: {
-              transform: function (propertyName, propertyValue) {
-                if (propertyName == 'background-image' && propertyValue.indexOf('/path/to') > -1) {
-                  return propertyValue.replace('/path/to', '../valid/path/to');
+          plugins: [
+            {
+              level1: {
+                value: function (propertyName, propertyValue) {
+                  if (propertyName == 'background-image' && propertyValue.indexOf('/path/to') > -1) {
+                    return propertyValue.replace('/path/to', '../valid/path/to');
+                  } else {
+                    return propertyValue;
+                  }
                 }
               }
             }
-          }
+          ]
         }).minify('.block{background-image:url(/path/to/image.png);border-image:url(image.png)}');
       },
       'gives right output': function (error, output) {
@@ -432,15 +451,17 @@ vows.describe('module tests').addBatch({
     'allows dropping properties': {
       'topic': function () {
         return new CleanCSS({
-          level: {
-            1: {
-              transform: function (propertyName) {
-                if (propertyName.indexOf('-o-') === 0) {
-                  return false;
+          plugins: [
+            {
+              level1: {
+                property: function (_rule, property) {
+                  if (property.name.indexOf('-o-') === 0) {
+                    property.unused = true;
+                  }
                 }
               }
             }
-          }
+          ]
         }).minify('.block{-o-border-radius:2px;border-image:url(image.png)}');
       },
       'gives right output': function (error, output) {
@@ -450,15 +471,17 @@ vows.describe('module tests').addBatch({
     'allows dropping properties based on selector': {
       'topic': function () {
         return new CleanCSS({
-          level: {
-            1: {
-              transform: function (propertyName, propertyValue, selector) {
-                if (propertyName.indexOf('-o-') === 0 && selector == '.block-2') {
-                  return false;
+          plugins: [
+            {
+              level1: {
+                property: function (rule, property) {
+                  if (rule == '.block-2' && property.name.indexOf('-o-') === 0) {
+                    property.unused = true;
+                  }
                 }
               }
             }
-          }
+          ]
         }).minify('.block-1{-o-border-radius:2px}.block-2{-o-border-radius:5px;width:1rem}');
       },
       'gives right output': function (error, output) {
@@ -468,14 +491,18 @@ vows.describe('module tests').addBatch({
     'combined with level 2 optimization': {
       'topic': function () {
         return new CleanCSS({
-          level: {
-            1: {
-              transform: function (propertyName) {
-                if (propertyName == 'margin-bottom') {
-                  return false;
+          plugins: [
+            {
+              level1: {
+                property: function (_rule, property) {
+                if (property.name == 'margin-bottom') {
+                    property.unused = true;
+                  }
                 }
               }
-            },
+            }
+          ],
+          level: {
             2: true
           }
         }).minify('.block{-o-border-radius:2px;margin:0 12px;margin-bottom:5px}');
@@ -489,7 +516,7 @@ vows.describe('module tests').addBatch({
     'relative': {
       'with rebase to the current directory': {
         'topic': function () {
-          return new CleanCSS().minify([
+          return new CleanCSS({ rebase: true }).minify([
             'test/fixtures/partials/one.css',
             'test/fixtures/partials/three.css'
           ]);
@@ -511,7 +538,7 @@ vows.describe('module tests').addBatch({
       },
       'without rebase': {
         'topic': function () {
-          return new CleanCSS({ rebase: false }).minify([
+          return new CleanCSS().minify([
             'test/fixtures/partials/one.css',
             'test/fixtures/partials/three.css'
           ]);
@@ -524,7 +551,7 @@ vows.describe('module tests').addBatch({
     'absolute': {
       'with rebase to the current directory': {
         'topic': function () {
-          return new CleanCSS().minify([
+          return new CleanCSS({ rebase: true }).minify([
             path.resolve('test/fixtures/partials/one.css'),
             path.resolve('test/fixtures/partials/three.css')
           ]);
@@ -546,7 +573,7 @@ vows.describe('module tests').addBatch({
       },
       'without rebase': {
         'topic': function () {
-          return new CleanCSS({ rebase: false }).minify([
+          return new CleanCSS().minify([
             path.resolve('test/fixtures/partials/one.css'),
             path.resolve('test/fixtures/partials/three.css')
           ]);
@@ -578,7 +605,7 @@ vows.describe('module tests').addBatch({
           return new CleanCSS({ inline: 'none' }).minify(['./test/fixtures/partials/remote.css', './test/fixtures/partials-absolute/base.css']);
         },
         'should give right output': function (minified) {
-          assert.equal(minified.styles, '@import url(http://jakubpawlowicz.com/styles.css);@import url(test/fixtures/partials-absolute/extra/sub.css);.base{margin:0}');
+          assert.equal(minified.styles, '@import url(http://clean-css.github.io/styles.css);@import url(test/fixtures/partials-absolute/extra/sub.css);.base{margin:0}');
         }
       },
       'off - many files with content': {
@@ -617,11 +644,38 @@ vows.describe('module tests').addBatch({
       }
     }
   },
+  'accepts a list of source files as array in batch mode': {
+    'with rebase to the current directory': {
+      'topic': function () {
+        return new CleanCSS({ batch: true, rebase: true, rebaseTo: process.cwd() }).minify([
+          'test/fixtures/partials/one.css',
+          'test/fixtures/partials/three.css'
+        ]);
+      },
+      'output should be a hash': function (minified) {
+        assert.equal(typeof minified, 'object');
+      },
+      'output should have input files as keys': function (minified) {
+        assert.isTrue('test/fixtures/partials/one.css' in minified);
+        assert.isTrue('test/fixtures/partials/three.css' in minified);
+      },
+      'output of first file should be in the first item': function (minified) {
+        assert.equal(minified['test/fixtures/partials/one.css'].styles, '.one{color:red}');
+        assert.deepEqual(minified['test/fixtures/partials/one.css'].errors, []);
+        assert.deepEqual(minified['test/fixtures/partials/one.css'].warnings, []);
+      },
+      'output of second file should be in the second item': function (minified) {
+        assert.equal(minified['test/fixtures/partials/three.css'].styles, '.three{background-image:url(test/fixtures/partials/extra/down.gif)}');
+        assert.deepEqual(minified['test/fixtures/partials/three.css'].errors, []);
+        assert.deepEqual(minified['test/fixtures/partials/three.css'].warnings, []);
+      }
+    }
+  },
   'accepts a list of source files as hash': {
     'relative': {
       'with rebase to the current directory': {
         'topic': function () {
-          return new CleanCSS().minify(
+          return new CleanCSS({ rebase: true }).minify(
             sourcesAsHash([
               'test/fixtures/partials/one.css',
               'test/fixtures/partials/three.css'
@@ -647,7 +701,7 @@ vows.describe('module tests').addBatch({
       },
       'without rebase': {
         'topic': function () {
-          return new CleanCSS({ rebase: false }).minify(
+          return new CleanCSS().minify(
             sourcesAsHash([
               'test/fixtures/partials/one.css',
               'test/fixtures/partials/three.css'
@@ -662,7 +716,7 @@ vows.describe('module tests').addBatch({
     'absolute': {
       'with rebase to the current directory': {
         'topic': function () {
-          return new CleanCSS().minify(
+          return new CleanCSS({ rebase: true }).minify(
             sourcesAsHash([
               'test/fixtures/partials/one.css',
               'test/fixtures/partials/three.css'
@@ -688,7 +742,7 @@ vows.describe('module tests').addBatch({
       },
       'without rebase': {
         'topic': function () {
-          return new CleanCSS({ rebase: false }).minify(
+          return new CleanCSS().minify(
             sourcesAsHash([
               'test/fixtures/partials/one.css',
               'test/fixtures/partials/three.css'
@@ -729,7 +783,7 @@ vows.describe('module tests').addBatch({
     },
     'with other imports and rebasing off': {
       'topic': function () {
-        return new CleanCSS({ rebase: false }).minify(
+        return new CleanCSS().minify(
           sourcesAsHash([
             'test/fixtures/partials/two.css'
           ])
@@ -767,7 +821,7 @@ vows.describe('module tests').addBatch({
     },
     'with a callback': {
       'topic': function () {
-        new CleanCSS().minify({
+        new CleanCSS({ rebase: true }).minify({
           'main.css': {
             styles: '@import url(test/fixtures/partials/one.css);\n@import url(test/fixtures/partials/three.css);'
           }
@@ -779,7 +833,7 @@ vows.describe('module tests').addBatch({
     },
     'with remote paths': {
       'topic': function() {
-        return new CleanCSS().minify({
+        return new CleanCSS({rebase: true}).minify({
           'http://127.0.0.1/styles.css': {
             styles: 'div{background-image:url(image.png)}'
           }
@@ -848,9 +902,63 @@ vows.describe('module tests').addBatch({
       }
     }
   },
+  'accepts a list of source files as hash in batch mode': {
+    'with rebase to the current directory': {
+      'topic': function () {
+        return new CleanCSS({ batch: true, rebase: true, rebaseTo: process.cwd() }).minify(
+          sourcesAsHash([
+            'test/fixtures/partials/one.css',
+            'test/fixtures/partials/three.css'
+          ])
+        );
+      },
+      'output should be a hash': function (minified) {
+        assert.equal(typeof minified, 'object');
+      },
+      'output should have input files as keys': function (minified) {
+        assert.isTrue('test/fixtures/partials/one.css' in minified);
+        assert.isTrue('test/fixtures/partials/three.css' in minified);
+      },
+      'output of first file should be in the first item': function (minified) {
+        assert.equal(minified['test/fixtures/partials/one.css'].styles, '.one{color:red}');
+        assert.deepEqual(minified['test/fixtures/partials/one.css'].errors, []);
+        assert.deepEqual(minified['test/fixtures/partials/one.css'].warnings, []);
+      },
+      'output of second file should be in the second item': function (minified) {
+        assert.equal(minified['test/fixtures/partials/three.css'].styles, '.three{background-image:url(extra/down.gif)}');
+        assert.deepEqual(minified['test/fixtures/partials/three.css'].errors, []);
+        assert.deepEqual(minified['test/fixtures/partials/three.css'].warnings, []);
+      }
+    }
+  },
+  'sources list as a hash in batch + promise mode': {
+    'with rebase to the current directory': {
+      'topic': function () {
+        var vow = this;
+
+        async function doTopic() {
+          return await new CleanCSS({ batch: true, returnPromise: true }).minify([
+            {'path/to/file/one': {styles: 'html { color: #000000; }'}},
+            {'path/to/file/two': {styles: 'body { background: #ffffff; }'}}
+          ]);
+        }
+
+        doTopic()
+          .then(function (output) { vow.callback(null, output); })
+          .catch(function (errors) { vow.callback(errors, null); });
+      },
+      'output should be a hash': function (minified) {
+        assert.equal(typeof minified, 'object');
+      },
+      'output should be correct': function (minified) {
+        assert.equal(minified['path/to/file/one'].styles, 'html{color:#000}');
+        assert.equal(minified['path/to/file/two'].styles, 'body{background:#fff}');
+      }
+    }
+  },
   'accepts a list of source files as array of hashes': {
     'topic': function () {
-      return new CleanCSS().minify([
+      return new CleanCSS({rebase: true}).minify([
         sourcesAsHash(['test/fixtures/partials/one.css']),
         sourcesAsHash(['test/fixtures/partials/three.css'])
       ]);
@@ -859,6 +967,31 @@ vows.describe('module tests').addBatch({
       assert.equal(minified.styles, '.one{color:red}.three{background-image:url(test/fixtures/partials/extra/down.gif)}');
     }
   },
+  'accepts a list of source files as array of hashes in batch mode': {
+    'topic': function () {
+      return new CleanCSS({ batch: true, rebase: true, rebaseTo: process.cwd() }).minify([
+        sourcesAsHash(['test/fixtures/partials/one.css']),
+        sourcesAsHash(['test/fixtures/partials/three.css'])
+      ]);
+    },
+    'output should be a hash': function (minified) {
+      assert.equal(typeof minified, 'object');
+    },
+    'output should have input files as keys': function (minified) {
+      assert.isTrue('test/fixtures/partials/one.css' in minified);
+      assert.isTrue('test/fixtures/partials/three.css' in minified);
+    },
+    'output of first file should be in the first item': function (minified) {
+      assert.equal(minified['test/fixtures/partials/one.css'].styles, '.one{color:red}');
+      assert.deepEqual(minified['test/fixtures/partials/one.css'].errors, []);
+      assert.deepEqual(minified['test/fixtures/partials/one.css'].warnings, []);
+    },
+    'output of second file should be in the second item': function (minified) {
+      assert.equal(minified['test/fixtures/partials/three.css'].styles, '.three{background-image:url(extra/down.gif)}');
+      assert.deepEqual(minified['test/fixtures/partials/three.css'].errors, []);
+      assert.deepEqual(minified['test/fixtures/partials/three.css'].warnings, []);
+    }
+  },
   'keeps trailing semicolons if option is set': {
     'topic': function() {
       return new CleanCSS({format: { semicolonAfterLastProperty: true }}).minify('*{ font-size:12px; color:#ea7500; }');
@@ -891,5 +1024,172 @@ vows.describe('module tests').addBatch({
         assert.isTrue(minified.stats.timeSpent < 1000);
       }
     }
+  },
+  'plugins': {
+    'level 1 - opacity range as value plugin': {
+      'topic': function () {
+        var opacityRangePlugin = {
+          level1: {
+            value: function (propertyName, propertyValue) {
+              if (propertyName == 'opacity' && parseFloat(propertyValue) < 0) {
+                return '0';
+              }
+
+              if (propertyName == 'opacity' && parseFloat(propertyValue) > 1) {
+                return '1';
+              }
+
+              return propertyValue;
+            }
+          }
+        };
+
+        return new CleanCSS({ plugins: [opacityRangePlugin]}).minify('.block-1{opacity:-1.5}.block-2{opacity:1.5}');
+      },
+      'normalizes opacity to standard boundaries': function (error, minified) {
+        assert.equal(minified.styles, '.block-1{opacity:0}.block-2{opacity:1}');
+      }
+    },
+    'level 1 - opacity range as property plugin': {
+      'topic': function () {
+        var opacityRangePlugin = {
+          level1: {
+            property: function (_rule, property) {
+              if (property.name == 'opacity' && parseFloat(property.value[0][1]) < 0) {
+                property.value[0][1] = '0';
+              }
+
+              if (property.name == 'opacity' && parseFloat(property.value[0][1]) > 1) {
+                property.value[0][1] = '1';
+              }
+            }
+          }
+        };
+
+        return new CleanCSS({ plugins: [opacityRangePlugin]}).minify('.block-1{opacity:-1.5}.block-2{opacity:1.5}');
+      },
+      'normalizes opacity to standard boundaries': function (error, minified) {
+        assert.equal(minified.styles, '.block-1{opacity:0}.block-2{opacity:1}');
+      }
+    },
+    'level 1 - background repeat plugin': {
+      'topic': function () {
+        var backgroundRepeatPlugin = {
+          level1: {
+            property: function(_rule, property) {
+              if (property.name == 'background-repeat' && property.value.length == 2 && property.value[0][1] == property.value[1][1]) {
+                property.value.pop();
+                property.dirty = true;
+              }
+            }
+          }
+        };
+
+        return new CleanCSS({ plugins: [backgroundRepeatPlugin]}).minify('.block-1{background-repeat:no-repeat}.block-2{background-repeat:repeat repeat}');
+      },
+      'normalizes opacity to standard boundaries': function (error, minified) {
+        assert.equal(minified.styles, '.block-1{background-repeat:no-repeat}.block-2{background-repeat:repeat}');
+      }
+    },
+    'level 1 - drop certain properties via a property plugin': {
+      'topic': function () {
+        // Let's say you bundle external CSS into yours and want to get rid of some properties programatically
+        // e.g. Bootstrap uses `-webkit-linear-gradient()`, `-o-linear-gradient()`, and `-webkit-gradient()` fallbacks and you want to get rid of them
+        var getRidOfBackgroundImageVendorFallbacks = {
+          level1: {
+            property: function (_rule, property) {
+              var value;
+
+              if (property.name == 'background-image') {
+                value = property.value[0][1];
+
+                if (value.indexOf('-webkit-linear-gradient') == 0 || value.indexOf('-o-linear-gradient') == 0 || value.indexOf('-webkit-gradient') == 0) {
+                  property.unused = true;
+                }
+              }
+            }
+          }
+        };
+
+        var input = '\
+          .block-1 {\
+            background-image: -webkit-linear-gradient(left, rgba(0, 0, 0, .0001) 0%, rgba(0, 0, 0, .5) 100%);\
+            background-image:      -o-linear-gradient(left, rgba(0, 0, 0, .0001) 0%, rgba(0, 0, 0, .5) 100%);\
+            background-image: -webkit-gradient(linear, left top, right top, from(rgba(0, 0, 0, .0001)), to(rgba(0, 0, 0, .5)));\
+            background-image:         linear-gradient(to right, rgba(0, 0, 0, .0001) 0%, rgba(0, 0, 0, .5) 100%);\
+          } \
+        ';
+
+        return new CleanCSS({ plugins: [getRidOfBackgroundImageVendorFallbacks]}).minify(input);
+      },
+      'normalizes opacity to standard boundaries': function (error, minified) {
+        assert.equal(minified.styles, '.block-1{background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%)}');
+      }
+    },
+    'level 2 - drop certain rules via level 2 plugin': {
+      'topic': function () {
+        // Let's say you bundle external CSS into yours and want to get rid of some rules programatically
+        // e.g. Bootstrap uses `glyphicon` classes and you don't need them at all
+        var getRidOfGlyphiconsPlugin = {
+          level2: {
+            block: function (tokens) {
+              // at this point you get full access to serialized CSS, do `console.log(tokens)` to see what you get
+              var tokenType;
+              var tokenNames;
+              var tokenValues;
+              var i, l;
+
+              for (i = 0, l = tokens.length; i < l; i++) {
+                tokenType = tokens[i][0];
+                tokenNames = tokens[i][1];
+                tokenValues = tokens[i][2];
+
+                if (tokenType == 'rule' && tokenNames[0][1].indexOf('.glyphicon') == 0) {
+                  tokens[i][2] = [];
+                }
+
+                if (tokenType == 'at-rule-block' && tokenNames[0][1] == '@font-face' && tokenValues.length > 0 && tokenValues[0][1][1] == 'font-family' && tokenValues[0][2][1].indexOf('Glyphicons') > -1) {
+                  tokens[i][2] = [];
+                }
+              }
+            }
+          }
+        };
+
+        var input = '\
+          td,\
+          th {\
+            padding: 0;\
+          }\
+          @font-face {\
+            font-family: \'Glyphicons Halflings\';\
+            src: url(\'../fonts/glyphicons-halflings-regular.eot\');\
+            src: url(\'../fonts/glyphicons-halflings-regular.eot?#iefix\') format(\'embedded-opentype\'), url(\'../fonts/glyphicons-halflings-regular.woff2\') format(\'woff2\'), url(\'../fonts/glyphicons-halflings-regular.woff\') format(\'woff\'), url(\'../fonts/glyphicons-halflings-regular.ttf\') format(\'truetype\'), url(\'../fonts/glyphicons-halflings-regular.svg#glyphicons_halflingsregular\') format(\'svg\');\
+          }\
+          .glyphicon {\
+            position: relative;\
+            top: 1px;\
+            display: inline-block;\
+            font-family: \'Glyphicons Halflings\';\
+            font-style: normal;\
+            font-weight: normal;\
+            line-height: 1;\
+            -webkit-font-smoothing: antialiased;\
+            -moz-osx-font-smoothing: grayscale;\
+          }\
+          .glyphicon-asterisk:before {\
+            content: "\\2a";\
+          }\
+          .glyphicon-plus:before {\
+            content: "\\2b";\
+          }\
+        ';
+
+        return new CleanCSS({ level: 2, plugins: [getRidOfGlyphiconsPlugin]}).minify(input);
+      },
+      'normalizes opacity to standard boundaries': function (error, minified) {
+        assert.equal(minified.styles, 'td,th{padding:0}');
+      }
+    }
   }
 }).export(module);
