@@ -247,6 +247,34 @@ vows.describe('level 1 optimizations')
       ]
     }, { level: 1, compatibility: { selectors: { adjacentSpace: true } } })
   )
+  .addBatch(
+    optimizerContext('selectors - rule list in a pseudo class', {
+      'space is not removed': [
+        ':host-context(main article){color:red}',
+        ':host-context(main article){color:red}'
+      ],
+      'extra spaces are removed': [
+        ':host-context(main   article){color:red}',
+        ':host-context(main article){color:red}'
+      ],
+      'extra spaces with comma are removed': [
+        ':host-context(main,   article){color:red}',
+        ':host-context(main,article){color:red}'
+      ],
+      'space is not removed in multiple rules': [
+        ':host-context(main footer),:host-context(main header){color:red}',
+        ':host-context(main footer),:host-context(main header){color:red}'
+      ],
+      'space is not removed from :not pseudo-class': [
+        ':not(.block1 .block1__block2){color:red}',
+        ':not(.block1 .block1__block2){color:red}'
+      ],
+      'space in scoped pseudo class': [
+        '.container:not(#BorlabsCookieBox .container){max-width:1280px!important}',
+        '.container:not(#BorlabsCookieBox .container){max-width:1280px!important}'
+      ]
+    }, { level: 1 })
+  )
   .addBatch(
     optimizerContext('selectors - disabled empty removal', {
       'no body': [
@@ -412,6 +440,18 @@ vows.describe('level 1 optimizations')
       '8-value hex': [
         '.block{color:#00ff0080}',
         '.block{color:#00ff0080}'
+      ],
+      'hsla with variables': [
+        '.block{color: hsl(0, 0%, calc((var(--button_color_l) - 65) * -100%))}',
+        '.block{color:hsl(0,0%,calc((var(--button_color_l) - 65) * -100%))}'
+      ],
+      'rgba inside a function #1': [
+        '.block{background-image:linear-gradient(to right,rgba(255,255,255,0),rgba(255,255,255,1))}',
+        '.block{background-image:linear-gradient(to right,rgba(255,255,255,0),#fff)}'
+      ],
+      'rgba inside a function #2': [
+        '.block{background:linear-gradient(hsla(0,0%,98%,.8),hsla(0,0%,98%,.8)) 0 0/100% 1px no-repeat #f0de98}',
+        '.block{background:linear-gradient(hsla(0,0%,98%,.8),hsla(0,0%,98%,.8)) 0 0/100% 1px no-repeat #f0de98}'
       ]
     }, { level: 1 })
   )
@@ -540,6 +580,10 @@ vows.describe('level 1 optimizations')
       'with mixed bold weight and variant #2': [
         'a{font:bold normal 17px sans-serif}',
         'a{font:bold normal 17px sans-serif}'
+      ],
+      'with color in local font name': [
+        '@font-face{src:local("Sans Black Italic")}',
+        '@font-face{src:local("Sans Black Italic")}',
       ]
     }, { level: 1 })
   )
@@ -611,6 +655,54 @@ vows.describe('level 1 optimizations')
       ]
     }, { level: 1 })
   )
+  .addBatch(
+    optimizerContext('ie hacks in IE11 mode', {
+      'underscore': [
+        'a{_width:101px}',
+        ''
+      ],
+      'asterisk': [
+        'a{*width:101px}',
+        ''
+      ],
+      '\\0 backslash': [
+        'a{width:101px\\0}',
+        'a{width:101px\\0}'
+      ],
+      '\\9 backslash': [
+        'a{width:101px\\9}',
+        'a{width:101px\\9}'
+      ],
+      'bang': [
+        'a{color:red !ie}',
+        ''
+      ]
+    }, { level: 1, compatibility: 'ie11' })
+  )
+  .addBatch(
+    optimizerContext('ie hacks in IE10 mode', {
+      'underscore': [
+        'a{_width:101px}',
+        ''
+      ],
+      'asterisk': [
+        'a{*width:101px}',
+        ''
+      ],
+      '\\0 backslash': [
+        'a{width:101px\\0}',
+        'a{width:101px\\0}'
+      ],
+      '\\9 backslash': [
+        'a{width:101px\\9}',
+        'a{width:101px\\9}'
+      ],
+      'bang': [
+        'a{color:red !ie}',
+        ''
+      ]
+    }, { level: 1, compatibility: 'ie10' })
+  )
   .addBatch(
     optimizerContext('ie hacks in IE9 mode', {
       'underscore': [
@@ -887,6 +979,30 @@ vows.describe('level 1 optimizations')
       ]
     }, { level: 1, compatibility: 'ie8' })
   )
+  .addBatch(
+    optimizerContext('rpx unit when disabled in level 1', {
+      'is kept': [
+        '.block{border:2rpx solid #ddd}',
+        '.block{border:2rpx solid #ddd}'
+      ]
+    }, { level: 1 })
+  )
+  .addBatch(
+    optimizerContext('rpx unit when disabled in level 2', {
+      'is removed': [
+        '.block{border:2rpx solid #ddd}',
+        '.block{border:solid #ddd}'
+      ]
+    }, { level: 2 })
+  )
+  .addBatch(
+    optimizerContext('rpx unit when enabled in level 2', {
+      'is removed': [
+        '.block{border:2rpx solid #ddd}',
+        '.block{border:2rpx solid #ddd}'
+      ]
+    }, { level: 2, compatibility: { customUnits: { rpx: true } } })
+  )
   .addBatch(
     optimizerContext('zeros', {
       '-0 to 0': [
@@ -984,6 +1100,22 @@ vows.describe('level 1 optimizations')
       'max-width': [
         'a{max-width:0%}',
         'a{max-width:0%}'
+      ],
+      'zero inside min function': [
+        '.block{width:min(0px, 30px)}',
+        '.block{width:min(0px,30px)}'
+      ],
+      'zero inside max function': [
+        '.block{width:max(0px, 30px)}',
+        '.block{width:max(0px,30px)}'
+      ],
+      'zero inside clamp function': [
+        '.block{width:clamp(0rem, 2.5vw, 2rem)}',
+        '.block{width:clamp(0rem,2.5vw,2rem)}'
+      ],
+      'inside calc inside a gradient': [
+        '.block{background:linear-gradient(red 0rem calc(50% - 0rem),#00f calc(50% + 0rem) 100%)}',
+        '.block{background:linear-gradient(red 0 calc(50% - 0rem),#00f calc(50% + 0rem) 100%)}'
       ]
     }, { level: 1 })
   )
@@ -1068,6 +1200,10 @@ vows.describe('level 1 optimizations')
       'line breaks and special comments inside a rule': [
         'a{\ncolor:red;\n/*!*/\n\n\n\n\n\n\n/*!*/\n}',
         'a{color:red/*!*//*!*/}'
+      ],
+      'inside URL': [
+        'a{background:url(    "about:blank"  )}',
+        'a{background:url("about:blank")}'
       ]
     }, { level: 1 })
   )
@@ -1225,6 +1361,10 @@ vows.describe('level 1 optimizations')
         '.block{-webkit-font-feature-settings:"scmp","swsh" 2}',
         '.block{-webkit-font-feature-settings:"scmp","swsh" 2}'
       ],
+      'grid': [
+        '.block{grid:"header" 20% "nav" auto/auto}',
+        '.block{grid:"header" 20% "nav" auto/auto}'
+      ],
       'grid-template': [
         '.block{grid-template:"header" 20% "nav" auto}',
         '.block{grid-template:"header" 20% "nav" auto}'
@@ -1243,6 +1383,18 @@ vows.describe('level 1 optimizations')
       ]
     }, { level: 1 })
   )
+  .addBatch(
+    optimizerContext('variable declaration', {
+      'with whitespace as value': [
+        'a{--test: }',
+        'a{--test: }'
+      ],
+      'multiple variables': [
+        'a{--test1: ;--test2: }',
+        'a{--test1: ;--test2: }'
+      ],
+    }, { level: 1 })
+  )
   .addBatch(
     optimizerContext('@charset cleanup off', {
       'stays where it is': [
