@@ -18,9 +18,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: true,
@@ -67,9 +64,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: true,
@@ -105,9 +99,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: true,
@@ -172,9 +163,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: true,
@@ -228,9 +216,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: false,
@@ -266,9 +251,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: false,
@@ -304,9 +286,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: true,
@@ -360,9 +339,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: true,
@@ -416,9 +392,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: true,
@@ -454,9 +427,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: true,
@@ -510,9 +480,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: true,
@@ -566,9 +533,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: true,
@@ -622,9 +586,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: true,
@@ -678,9 +639,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: true,
@@ -716,9 +674,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: true,
@@ -771,9 +726,6 @@ vows.describe(optimizationLevelFrom)
         assert.deepEqual(levelOptions['0'], {});
       },
       'has level 1 options': function (levelOptions) {
-        assert.isTrue(typeof levelOptions['1'].transform == 'function');
-        delete levelOptions['1'].transform;
-
         assert.deepEqual(levelOptions['1'], {
           cleanupCharsets: true,
           normalizeUrls: true,
